@@ -1,14 +1,13 @@
-# -*-cperl-*-
 package AFS;
 
 #------------------------------------------------------------------------------
-# RCS-Id: "@(#)$Id: AFS.pm 881 2008-10-26 18:58:51Z nog $"
+# RCS-Id: "@(#)$Id: AFS.pm 1054 2011-11-17 11:51:37Z nog $"
 #
 # This library is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 #
-# Copyright  2001-2005 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
-# Copyright  1994 Board of Trustees, Leland Stanford Jr. University.
+# © 2001-2011 Norbert E. Gruener <nog@MPA-Garching.MPG.de>
+# © 1994 Board of Trustees, Leland Stanford Jr. University.
 #
 #  The original library is covered by the following copyright:
 #
@@ -31,12 +30,11 @@ require Exporter;
 require AutoLoader;
 require DynaLoader;
 
-use vars qw(@ISA $VERSION $REVISION);
+use vars qw(@ISA $VERSION);
 
 @ISA = qw(Exporter AutoLoader DynaLoader);
 
-$VERSION = '2.6.1';
-$REVISION = do{my@r=q/Major Version 2.4 $Rev: 881 $/=~/\d+/g;$r[1]-=0;sprintf'%d.'.'%d'.'.%02d'x($#r-1),@r;};
+$VERSION = 'v2.6.3';
 
 @CELL = qw (
             configdir
@@ -277,6 +275,10 @@ sub AUTOLOAD {
     goto &$AUTOLOAD;
 }
 
+END {
+    AFS::_finalize();
+}
+
 bootstrap AFS;
 
 # Preloaded methods go here.  Autoload methods go after __END__, and are
